import { Link } from 'react-router-dom';
import { Github, Linkedin, Mail, Twitter, Heart, Code } from 'lucide-react';
import type { NavigationItem } from '../../types';

// Custom SVG Components for company icons
const StackOverflowIcon = ({ size = 20 }: { size?: number }) => (
  <svg width={size} height={size} viewBox="0 0 24 24" fill="currentColor">
    <path d="M15.725 0l-1.72 1.277 6.39 8.588 1.716-1.277L15.725 0zm-3.94 3.418l-1.369 1.644 8.225 6.85 1.369-1.644-8.225-6.85zm-3.15 4.465l-.905 1.94 9.702 4.517.904-1.94-9.701-4.517zm-1.85 4.86l-.44 2.093 10.473 2.201.44-2.092-10.473-2.203zM1.89 15.47V24h19.19v-8.53h-2.133v6.397H4.021v-6.396H1.89zm4.265 2.133v2.13h10.66v-2.13H6.154z" />
  </svg>
);

const GoogleDeveloperIcon = ({ size = 20 }: { size?: number }) => (
  <svg width={size} height={size} viewBox="0 0 24 24" fill="currentColor">
    <path d="M12.48 10.92v3.28h7.84c-.24 1.84-.853 3.187-1.787 4.133-1.147 1.147-2.933 2.4-6.053 2.4-4.827 0-8.6-3.893-8.6-8.72s3.773-8.72 8.6-8.72c2.6 0 4.507 1.027 5.907 2.347l2.307-2.307C18.747 1.44 16.133 0 12.48 0 5.867 0 .307 5.387.307 12s5.56 12 12.173 12c3.573 0 6.267-1.173 8.373-3.36 2.16-2.16 2.84-5.213 2.84-7.667 0-.76-.053-1.467-.173-2.053H12.48z" />
  </svg>
);

const footerNavigation: NavigationItem[] = [
  { id: 'home', label: 'Home', href: '/' },
  { id: 'about', label: 'About', href: '/about' },
  { id: 'skills', label: 'Skills', href: '/skills' },
  { id: 'projects', label: 'Projects', href: '/projects' },
  { id: 'blog', label: 'Blog', href: '/blog' },
  { id: 'learn', label: 'Learning Hub', href: '/learning' },
  { id: 'contact', label: 'Contact', href: '/contact' },
];

const quickLinks: NavigationItem[] = [
  { id: 'getting-started', label: 'Getting Started', href: '/learning/getting-started/overview' },
  { id: 'web-fundamentals', label: 'Web Fundamentals', href: '/learning/web-fundamentals/html5-mastery' },
  { id: 'frontend-dev', label: 'Frontend Development', href: '/learning/frontend-development/react-fundamentals' },
  { id: 'backend-dev', label: 'Backend Development', href: '/learning/backend-development/nodejs-express' },
  { id: 'dev-to-blog', label: 'Dev.to Blog', href: 'https://dev.to/mohitsuthar', external: true },
];



export default function Footer() {
  const currentYear = new Date().getFullYear();

  return (
    <footer className="bg-gray-50 dark:bg-gray-900 border-t border-gray-200 dark:border-gray-700">      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">        {/* Main footer content */}
      <div className="py-6 grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-4">
        {/* About section */}
        <div className="lg:col-span-2">            <div className="flex items-center space-x-2 mb-3">
          <div className="w-8 h-8 bg-gradient-to-r from-primary-600 to-secondary-500 rounded-lg flex items-center justify-center">
            <span className="text-white font-bold text-sm">MS</span>
          </div>
          <div>
            <h2 className="font-heading font-bold text-lg text-gray-900 dark:text-white">
              Mohit Suthar
            </h2>
            <p className="text-sm text-gray-600 dark:text-gray-400">
              Full-Stack Software Developer
            </p>
          </div>
        </div>
          <p className="text-base text-gray-600 dark:text-gray-400 mb-4 max-w-md leading-relaxed">
            Passionate about creating amazing web experiences and sharing knowledge
            with the developer community. Helping developers grow through
            comprehensive tutorials and hands-on projects.
          </p>{/* Social links */}
          <div className="flex items-center space-x-2">
            <a
              href="https://github.com/MohitSutharOfficial"
              target="_blank"
              rel="noopener noreferrer"
              className="p-1.5 rounded-md bg-gray-100 dark:bg-gray-800 text-gray-800 dark:text-gray-200 hover:bg-gray-900 hover:text-white dark:hover:bg-gray-700 transition-all"
              aria-label="GitHub"
            >
              <Github size={16} />
            </a>
            <a
              href="https://www.linkedin.com/in/mohit-suthar-4136a52a6/"
              target="_blank"
              rel="noopener noreferrer"
              className="p-1.5 rounded-md bg-blue-50 dark:bg-gray-800 text-blue-600 dark:text-blue-400 hover:bg-blue-600 hover:text-white dark:hover:bg-blue-600 transition-all"
              aria-label="LinkedIn"
            >
              <Linkedin size={16} />
            </a>
            <a
              href="https://x.com/OfficialMsuthar"
              target="_blank"
              rel="noopener noreferrer"
              className="p-1.5 rounded-md bg-gray-100 dark:bg-gray-800 text-gray-800 dark:text-gray-200 hover:bg-black hover:text-white dark:hover:bg-gray-700 transition-all"
              aria-label="Twitter"
            >
              <Twitter size={16} />
            </a>
            <a
              href="https://dev.to/mohitsuthar"
              target="_blank"
              rel="noopener noreferrer"
              className="p-1.5 rounded-md bg-gray-100 dark:bg-gray-800 text-gray-800 dark:text-gray-200 hover:bg-black hover:text-white dark:hover:bg-gray-700 transition-all"
              aria-label="Dev.to"
            >
              <Code size={16} />
            </a>
            <a
              href="https://stackoverflow.com/users/27745870/mohit-suthar"
              target="_blank"
              rel="noopener noreferrer"
              className="p-1.5 rounded-md bg-orange-50 dark:bg-gray-800 text-orange-600 dark:text-orange-400 hover:bg-orange-600 hover:text-white dark:hover:bg-orange-600 transition-all"
              aria-label="Stack Overflow"
            >
              <StackOverflowIcon size={16} />
            </a>
            <a
              href="https://developers.google.com/profile/u/104076667807103081699"
              target="_blank"
              rel="noopener noreferrer"
              className="p-1.5 rounded-md bg-blue-50 dark:bg-gray-800 text-blue-500 dark:text-blue-400 hover:bg-blue-500 hover:text-white dark:hover:bg-blue-500 transition-all"
              aria-label="Google Developers"
            >
              <GoogleDeveloperIcon size={16} />
            </a>
            <a
              href="mailto:kingmohitsuthar@gmail.com"
              className="p-1.5 rounded-md bg-green-50 dark:bg-gray-800 text-green-600 dark:text-green-400 hover:bg-green-600 hover:text-white dark:hover:bg-green-600 transition-all"
              aria-label="Email"
            >
              <Mail size={16} />
            </a>
          </div>
        </div>
        {/* Quick Navigation */}
        <div>
          <h3 className="font-heading font-semibold text-base text-gray-900 dark:text-white mb-2">
            Navigation
          </h3>
          <ul className="space-y-1">
            {footerNavigation.map((item) => (
              <li key={item.id}>
                <Link
                  to={item.href}
                  className="text-sm text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-colors leading-tight"
                >
                  {item.label}
                </Link>
              </li>
            ))}
          </ul>
        </div>

        {/* Quick Links */}
        <div>
          <h3 className="font-heading font-semibold text-base text-gray-900 dark:text-white mb-2">
            Quick Links
          </h3>
          <ul className="space-y-1">
            {quickLinks.map((item) => (
              <li key={item.id}>
                {item.external ? (
                  <a
                    href={item.href}
                    target="_blank"
                    rel="noopener noreferrer"
                    className="text-sm text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-colors leading-tight"
                  >
                    {item.label}
                  </a>
                ) : (
                  <Link
                    to={item.href}
                    className="text-sm text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-colors leading-tight"
                  >
                    {item.label}
                  </Link>
                )}
              </li>
            ))}
          </ul>
        </div>
      </div>        {/* Newsletter signup */}
      <div className="py-4 border-t border-gray-200 dark:border-gray-700">
        <div className="max-w-md">
          <h3 className="font-heading font-semibold text-base text-gray-900 dark:text-white mb-2">
            Stay Updated
          </h3>
          <p className="text-sm text-gray-600 dark:text-gray-400 mb-3">
            Get the latest blog posts and learning resources delivered to your inbox.
          </p>
          <form className="flex gap-2">
            <input
              type="email"
              placeholder="Enter your email"
              className="flex-1 px-3 py-2 text-sm border border-gray-300 dark:border-gray-600 rounded-md bg-white dark:bg-gray-800 text-gray-900 dark:text-white placeholder-gray-500 dark:placeholder-gray-400 focus:outline-none focus:ring-2 focus:ring-primary-500 focus:border-transparent"
            />
            <button
              type="submit"
              className="px-4 py-2 bg-primary-600 hover:bg-primary-700 text-white text-sm font-medium rounded-md transition-colors whitespace-nowrap"
            >
              Subscribe
            </button>
          </form>
        </div>
      </div>

      {/* Bottom section */}
      <div className="py-4 border-t border-gray-200 dark:border-gray-700">
        <div className="flex flex-col md:flex-row justify-between items-center space-y-2 md:space-y-0">            <div className="flex items-center space-x-1 text-sm text-gray-600 dark:text-gray-400">
          <span>© {currentYear} Mohit Suthar. Made By</span>
          <Heart size={14} className="text-red-500" />
          <span>Mohit.</span>
        </div>

          <div className="flex items-center space-x-4 text-sm">
            <Link
              to="/privacy"
              className="text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-colors"
            >
              Privacy Policy
            </Link>
            <Link
              to="/terms"
              className="text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-colors"
            >
              Terms of Service
            </Link>
            <a
              href="/sitemap.xml"
              className="text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-colors"
              target="_blank"
              rel="noopener noreferrer"
            >
              Sitemap
            </a>
          </div>
        </div>
      </div>
    </div>
    </footer>
  );
}
